Installation
============

From PyPI
*********

For your convenience, `renderspec` is also available from the Cheese
Shop:

.. code-block:: shell

   pip install renderspec

From source
***********

If you want to hack `renderspec` or just have the latest version without
waiting for next release, use the git repo directly a la

.. code-block:: shell

   git clone https://git.openstack.org/openstack/renderspec
   cd renderspec
   python setup.py develop --user
